##############################################################################
#
# Copyright (c) 2004 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Zope Application Server setup package."""
from zope.app.appsetup.appsetup import config, database  # noqa: F401

# BBB
from zope.app.appsetup.interfaces import IDatabaseOpenedEvent, DatabaseOpened  # noqa: F401,E501
from zope.app.appsetup.interfaces import IProcessStartingEvent, ProcessStarting  # noqa: F401,E501
